@@ -1,46 +1,24 @@
 __all__ = ('IdentificationProcessPoint', 'AutoIdentificationTaskPoint')
 
 from expressmoney.api import *
-from expressmoney.viewflow import status
+from expressmoney.viewflow import result
 
 SERVICE = 'profiles'
 
 
 class IdentificationProcessReadContract(Contract):
-    EMPTY = status.EMPTY
-    SUCCESS = status.SUCCESS
-    FAILURE = status.FAILURE
-
-    RESULT_CHOICES = (
-        (EMPTY, EMPTY),
-        (SUCCESS, SUCCESS),
-        (FAILURE, FAILURE),
-    )
     id = serializers.IntegerField(min_value=1)
     updated = serializers.DateField()
     user_id = serializers.IntegerField(min_value=1)
-    result = serializers.ChoiceField(choices=RESULT_CHOICES)
+    result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
     status = serializers.CharField(max_length=50)
 
 
 class AutoIdentificationTaskReadContract(Contract):
-    EMPTY = status.EMPTY
-    SUCCESS = status.SUCCESS
-    FAILURE = status.FAILURE
-    RESULT_CHOICES = (
-        (EMPTY, EMPTY),
-        (SUCCESS, SUCCESS),
-        (FAILURE, FAILURE),
-    )
-    RU = 'RU'
-    COUNTRY_CHOICES = (
-        (RU, RU),
-    )
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
-    country = serializers.ChoiceField(choices=COUNTRY_CHOICES)
-    result = serializers.ChoiceField(choices=RESULT_CHOICES)
+    result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
 
 
